@@ -14,15 +14,16 @@ CURDIR=$(pwd)
 TMPDIR=`mktemp -d libjna-tmp.XXXXXX`
 BASEDIR=$TMPDIR/libjna-java-${VERSION}
 mkdir ${BASEDIR}
+TARGET=$(dirname "$3")/libjna-java_${VERSION}.orig.tar.gz
 
 # retrieve sources from svn
-# svn export https://jna.dev.java.net/svn/jna/tags/${VERSION}/jnalib/ --username guest ${BASEDIR}
-wget --user guest --password "" \
+# svn export https://svn.java.net/svn/jna~svn/tags/${VERSION}/jnalib/ --username guest ${BASEDIR}
+wget --no-check-certificate \
       --directory-prefix=${TMPDIR} \
-      https://jna.dev.java.net/svn/jna/tags/${VERSION}/jnalib/pom.xml \
-      https://jna.dev.java.net/svn/jna/tags/${VERSION}/jnalib/dist/src.zip \
-      https://jna.dev.java.net/svn/jna/tags/${VERSION}/jnalib/src/com/sun/jna/overview.html \
-      https://jna.dev.java.net/svn/jna/tags/${VERSION}/jnalib/src/com/sun/jna/package.html
+      https://svn.java.net/svn/jna~svn/tags/${VERSION}/jnalib/pom.xml \
+      https://svn.java.net/svn/jna~svn/tags/${VERSION}/jnalib/dist/src.zip \
+      https://svn.java.net/svn/jna~svn/tags/${VERSION}/jnalib/src/com/sun/jna/overview.html \
+      https://svn.java.net/svn/jna~svn/tags/${VERSION}/jnalib/src/com/sun/jna/package.html
 
 unzip -d ${BASEDIR} ${TMPDIR}/src.zip
 
@@ -37,7 +38,7 @@ mv ${TMPDIR}/*html ${BASEDIR}/src/com/sun/jna/
 mv ${TMPDIR}/*xml ${BASEDIR}/
 
 # Repack
-GZIP=-9 tar -C "$TMPDIR" -czf ../libjna-java_${VERSION}.orig.tar.gz "libjna-java-${VERSION}"
+GZIP=-9 tar -C "$TMPDIR" -czf "${TARGET}" "libjna-java-${VERSION}"
 
 # Clean temporary files
 rm -rf "$TMPDIR"
@@ -46,5 +47,5 @@ rm -f "$FILENAME"
 
 if [ $1 = --upstream-version ] ;
 then
-    uupdate --upstream-version $2 $3
+    uupdate --upstream-version $2 "${TARGET}"
 fi
